# Generated by Django 3.2.8 on 2021-10-08 12:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('Deployment', '0003_pickle'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pickle',
            name='pickle_file',
            field=models.FileField(upload_to='naga/'),
        ),
    ]
