# Generated by Django 3.2.8 on 2021-10-07 11:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('Deployment', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='deployed_data',
            name='bathrooms',
            field=models.IntegerField(default=0),
        ),
        migrations.AlterField(
            model_name='deployed_data',
            name='number_of_bedrooms',
            field=models.IntegerField(default=0),
        ),
        migrations.AlterField(
            model_name='deployed_data',
            name='number_of_car_spots',
            field=models.IntegerField(default=0),
        ),
        migrations.AlterField(
            model_name='deployed_data',
            name='rooms',
            field=models.IntegerField(default=0),
        ),
    ]
