{% load static %}
{% load widget_tweaks %}
{% load crispy_forms_tags %}
<html lang="en">
<head>

<meta charset="utf-8">
<meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
	<link rel="stylesheet" href="{% static 'css/bootstrap.min.css' %}">
        <link rel="stylesheet" media="screen" href="{% static 'css/tiny_slider.css' %}"/>
        <link rel="stylesheet" media="screen" href="{% static 'css/simple.css' %}"/>
        <link rel="stylesheet" media="screen" href="{% static 'css/theme_min.css' %}">
        <link rel="stylesheet" href="{% static 'css/smtp1.css' %}">
	    <link rel="stylesheet" href="{% static 'css/smtp2.css' %}">
	    <link rel="stylesheet" href="{% static 'css/smtp3.css' %}">
	    <link rel="stylesheet" href="{% static 'css/smtp4.css' %}">
	    <link rel="stylesheet" href="{% static 'css/smtp5.css' %}">


</head>
<body>
<div class="content">
<div class="container">
<div class="row">
<div class="col-md-6">
	<img src="{% static 'images/bg.svg' %}" alt="Image" class="img-fluid" width="500" height="500">
</div>
<div class="col-md-6 contents">
<div class="row justify-content-center">
<div class="col-md-9">
<!--	{{pre_form|crispy}}-->
<div class="card-header pb-0 text-left">
		<h4 class="font-weight-bolder text-primary text-gradient">House Price Prediction in AUS </h4>

	</div>

<form action="{% url 'Deployment:home' %}" method="post">

	{% csrf_token %}

                      {% for field in pre_form %}

                                            {{field.label}}
                                            {% render_field field class="form-control" %}
                                            {{field.errors}}
                      {% endfor %}


			<div class="text-center">
<!--				<a rel="stylesheet" href="" class="btn bg-gradient-primary w-100 mt-4 mb-0">SignUp</a>-->
				<input type="submit" value="Predict Price" name="idea_sub" class="btn bg-gradient-primary w-60 mt-4 mb-0">
			</div>
		</form>

	<b><font color="green"> {{cost}}</font></b>

</div>
</div>
</div>
</div>
</div>
</div>
<script src="js/jquery-3.3.1.min.js"></script>
<script src="js/popper.min.js"></script>
<script src="js/bootstrap.min.js"></script>
<script src="js/main.js"></script>
<script defer src="https://static.cloudflareinsights.com/beacon.min.js" data-cf-beacon='{"rayId":"69a82e32e8f03971","token":"cd0b4b3a733644fc843ef0b185f98241","version":"2021.9.0","si":100}'></script>
</body>
</html>