# Generated by Django 3.2.8 on 2021-10-08 04:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('Deployment', '0002_auto_20211007_1724'),
    ]

    operations = [
        migrations.CreateModel(
            name='Pickle',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('pickle_file', models.FileField(upload_to='\\pickle')),
            ],
        ),
    ]
